@@ -20,6 +20,26 @@ class PyTestRunner(RunnerBase):
     module = 'pytest'
     name = 'pytest'
 
+    def get_versions(self):
+        """Return versions of framework and its plugins."""
+        import pytest
+        versions = ['pytest {}'.format(pytest.__version__)]
+
+        class GetPluginVersionsPlugin():
+            def pytest_cmdline_main(self, config):
+                nonlocal versions
+                plugininfo = config.pluginmanager.list_plugin_distinfo()
+                if plugininfo:
+                    for plugin, dist in plugininfo:
+                        versions.append("   {} {}".format(dist.project_name,
+                                                          dist.version))
+
+        # --capture=sys needed on Windows to avoid
+        # ValueError: saved filedescriptor not valid anymore
+        pytest.main(['-V', '--capture=sys'],
+                    plugins=[GetPluginVersionsPlugin()])
+        return versions
+
     def create_argument_list(self):
         """Create argument list for testing process."""
         pyfile = os.path.join(os.path.dirname(__file__), 'pytestworker.py')
@@ -47,7 +67,9 @@ class PyTestRunner(RunnerBase):
         result_list = []
 
         for result_item in output:
-            if result_item['event'] == 'collected':
+            if result_item['event'] == 'config':
+                self.rootdir = result_item['rootdir']
+            elif result_item['event'] == 'collected':
                 testname = convert_nodeid_to_testname(result_item['nodeid'])
                 collected_list.append(testname)
             elif result_item['event'] == 'collecterror':
@@ -56,10 +78,8 @@ class PyTestRunner(RunnerBase):
             elif result_item['event'] == 'starttest':
                 starttest_list.append(logreport_starttest_to_str(result_item))
             elif result_item['event'] == 'logreport':
-                testresult = logreport_to_testresult(result_item, self.config)
+                testresult = logreport_to_testresult(result_item, self.rootdir)
                 result_list.append(testresult)
-            elif result_item['event'] == 'finished':
-                self.output = result_item['stdout']
 
         if collected_list:
             self.sig_collected.emit(collected_list)
@@ -78,7 +98,7 @@ class PyTestRunner(RunnerBase):
         """
         self.reader.close()
         output = self.read_all_process_output()
-        self.sig_finished.emit(None, output)
+        self.sig_finished.emit([] if "no tests ran" in output else None, output)
 
 
 def normalize_module_name(name):
@@ -111,32 +131,25 @@ def logreport_starttest_to_str(report):
     return convert_nodeid_to_testname(report['nodeid'])
 
 
-def logreport_to_testresult(report, config):
+def logreport_to_testresult(report, rootdir):
     """Convert a logreport sent by test process to a TestResult."""
-    if report['outcome'] == 'passed':
-        cat = Category.OK
-        status = 'ok'
-    elif report['outcome'] == 'failed':
+    status = report['outcome']
+    if report['outcome'] in ('failed', 'xpassed') or report['witherror']:
         cat = Category.FAIL
-        status = 'failure'
+    elif report['outcome'] in ('passed', 'xfailed'):
+        cat = Category.OK
     else:
         cat = Category.SKIP
-        status = report['outcome']
     testname = convert_nodeid_to_testname(report['nodeid'])
-    duration = report['duration']
-    message = report['message'] if 'message' in report else ''
-    if 'longrepr' not in report:
-        extra_text = ''
-    elif isinstance(report['longrepr'], tuple):
-        extra_text = report['longrepr'][2]
-    else:
-        extra_text = report['longrepr']
+    message = report.get('message', '')
+    extra_text = report.get('longrepr', '')
     if 'sections' in report:
+        if extra_text:
+            extra_text +=  '\n'
         for (heading, text) in report['sections']:
-            extra_text += '----- {} -----\n'.format(heading)
-            extra_text += text
-    filename = osp.join(config.wdir, report['filename'])
+            extra_text += '----- {} -----\n{}'.format(heading, text)
+    filename = osp.join(rootdir, report['filename'])
     result = TestResult(cat, status, testname, message=message,
-                        time=duration, extra_text=extra_text,
+                        time=report['duration'], extra_text=extra_text,
                         filename=filename, lineno=report['lineno'])
     return result
