@@ -13,7 +13,7 @@ import tempfile
 from qtpy.QtCore import (QObject, QProcess, QProcessEnvironment, QTextCodec,
                          Signal)
 from spyder.py3compat import to_text_string
-from spyder.utils.misc import add_pathlist_to_PYTHONPATH, get_python_executable
+from spyder.utils.misc import get_python_executable
 
 try:
     from importlib.util import find_spec as find_spec_or_loader
@@ -102,6 +102,8 @@ class RunnerBase(QObject):
     sig_finished(list of TestResult, str)
         Emitted when test process finishes. First argument contains the test
         results, second argument contains the output of the test process.
+    sig_stop()
+        Emitted when test process is being stopped.
     """
 
     sig_collected = Signal(object)
@@ -109,6 +111,7 @@ class RunnerBase(QObject):
     sig_starttest = Signal(object)
     sig_testresult = Signal(object)
     sig_finished = Signal(object, str)
+    sig_stop = Signal()
 
     def __init__(self, widget, resultfilename=None):
         """
@@ -144,6 +147,20 @@ class RunnerBase(QObject):
         """
         return find_spec_or_loader(cls.module) is not None
 
+    def get_versions(self):
+        """
+        Return versions of framework and its installed plugins.
+
+        This function must only be called for installed frameworks.
+
+        Returns
+        -------
+        list of str
+            Strings with framework or plugin name, followed by
+            its version.
+        """
+        raise NotImplementedError
+
     def create_argument_list(self):
         """
         Create argument list for testing process (dummy).
@@ -162,17 +179,14 @@ class RunnerBase(QObject):
         process.setProcessChannelMode(QProcess.MergedChannels)
         process.setWorkingDirectory(config.wdir)
         process.finished.connect(self.finished)
-        if pythonpath is not None:
-            env = [
-                to_text_string(_pth)
-                for _pth in process.systemEnvironment()
-            ]
-            add_pathlist_to_PYTHONPATH(env, pythonpath)
-            processEnvironment = QProcessEnvironment()
-            for envItem in env:
-                envName, separator, envValue = envItem.partition('=')
-                processEnvironment.insert(envName, envValue)
-            process.setProcessEnvironment(processEnvironment)
+        if pythonpath:
+            env = QProcessEnvironment.systemEnvironment()
+            old_python_path = env.value('PYTHONPATH', None)
+            python_path_str = os.pathsep.join(pythonpath)
+            if old_python_path:
+                python_path_str += os.pathsep + old_python_path
+            env.insert('PYTHONPATH', python_path_str)
+            process.setProcessEnvironment(env)
         return process
 
     def start(self, config, pythonpath):
@@ -228,3 +242,4 @@ class RunnerBase(QObject):
         """Stop testing process if it is running."""
         if self.process and self.process.state() == QProcess.Running:
             self.process.kill()
+            self.sig_stop.emit()
